Group: Engineering
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
Name:           sympow
Version:        2.023.6
Release:        alt2_10
Summary:        Special Values of Symmetric Power Elliptic Curve L-Functions

# The License tag is a lie.  See
# https://gitlab.com/rezozer/forks/sympow/-/issues/7
License:        BSD-2-Clause AND GPL-2.0-or-later
URL:            https://gitlab.com/rezozer/forks/sympow
Source0:        https://gitlab.com/rezozer/forks/sympow/-/archive/v%{version}/%{name}-v%{version}.tar.bz2
# Do not try to create the cachedir; RPM already created it
Patch0:         sympow-2.023.5-cachedir.patch
# Upstream patch to fix a crash
# https://gitlab.com/rezozer/forks/sympow/-/merge_requests/4
Patch1:         sympow-2.023.6-crash.patch
BuildRequires:  autoconf
BuildRequires:  gcc
BuildRequires:  help2man
BuildRequires:  pari-gp

# See https://fedoraproject.org/wiki/Changes/EncourageI686LeafRemoval
ExcludeArch:    %{ix86}

Requires:       %{name}-data = %{version}-%{release}
Requires:       grep
Requires:       pari-gp
Requires:       sed
Source44: import.info

%description
SYMPOW is a program for computing special values of symmetric power
elliptic curve L-functions.

%package        data
Group: Engineering
Summary:        Shared data for sympow
BuildArch:      noarch

%description    data
This package provides the essential SYMPOW architecture-independent
material, namely shared data and scripts.


%prep
%setup -q -n %{name}-v%{version}
%patch0 -p1
%patch1 -p1



%build
export PREFIX="%{_prefix}"
./Configure

# Do not override Fedora flags
sed -i 's/-O3 //' Makefile

# Put the helper script in a canonical place
cat >> config.h << EOF
#define PKGLIBDIR "%{_libexecdir}/%{name}"
EOF
sed -i 's,%{_prefix}/lib/%{name},%{_libexecdir}/%{name},' Makefile

%make_build


%install
%makeinstall_std
mkdir -p %{buildroot}%{_var}/cache/%{name}

# The install step creates the txt files, so we cannot convert them to bin
# files until now.
mkdir -p binfiles/$(config/endiantuple)
for fil in datafiles/*.txt; do
  NUM=$(grep -Fc AT ${fil} || :)
  if [ "$NUM" -gt 0 ]; then
    ./sympow -txt2bin $NUM binfiles/$(config/endiantuple)/$(basename ${fil/txt/bin}) < $fil
  fi
done
chmod 0644 binfiles/$(config/endiantuple)/*.bin
cp -a binfiles %{buildroot}%{_var}/cache/%{name}/datafiles


%files
%doc HISTORY README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1*
%{_var}/cache/%{name}/

%files data
%doc --no-dereference COPYING
%{_datadir}/%{name}/
%{_libexecdir}/%{name}/


%changelog
* Sat Mar 23 2024 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_10
- update to new release by fcimport

* Thu Aug 31 2023 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_9
- update to new release by fcimport

* Wed Feb 22 2023 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_8
- update to new release by fcimport

* Sun Aug 07 2022 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_6
- update to new release by fcimport

* Sat Feb 05 2022 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_5
- update to new release by fcimport

* Mon Aug 02 2021 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_4
- update to new release by fcimport

* Wed Mar 17 2021 Igor Vlasenko <viy@altlinux.org> 2.023.6-alt2_3
- update to new release by fcimport

* Wed Jan 27 2021 Igor Vlasenko <viy@altlinux.ru> 2.023.6-alt2_2
- update to new release by fcimport

* Wed Sep 02 2020 Igor Vlasenko <viy@altlinux.ru> 2.023.6-alt1_2
- update to new release by fcimport

* Thu Feb 27 2020 Igor Vlasenko <viy@altlinux.ru> 2.023.5-alt1_4
- update to new release by fcimport

* Tue Aug 06 2019 Igor Vlasenko <viy@altlinux.ru> 2.023.5-alt1_2
- update to new release by fcimport

* Mon Jul 01 2019 Igor Vlasenko <viy@altlinux.ru> 2.023.5-alt1_1
- update to new release by fcimport

* Wed Apr 04 2018 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_17
- update to new release by fcimport

* Mon Oct 09 2017 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_16
- update to new release by fcimport

* Wed Mar 15 2017 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_14
- update to new release by fcimport

* Wed Mar 02 2016 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_13
- update to new release by fcimport

* Mon Oct 19 2015 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_12
- update to new release by fcimport

* Tue Sep 16 2014 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_11
- update to new release by fcimport

* Mon Jul 07 2014 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_10
- update to new release by fcimport

* Mon Sep 09 2013 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_9
- update to new release by fcimport

* Mon Apr 29 2013 Igor Vlasenko <viy@altlinux.ru> 1.019-alt1_8
- initial fc import

